package com.tanpu.community.controller;

import com.tanpu.common.api.CommonResp;
import com.tanpu.common.auth.AuthLogin;
import com.tanpu.common.auth.UserHolder;
import com.tanpu.community.api.beans.qo.FollowQo;
import com.tanpu.community.api.beans.qo.ThemeQo;
import com.tanpu.community.api.beans.req.homepage.FollowRelReq;
import com.tanpu.community.api.beans.req.homepage.QueryFollowReq;
import com.tanpu.community.api.beans.req.homepage.QueryRecordThemeReq;
import com.tanpu.community.api.beans.req.page.Page;
import com.tanpu.community.manager.HomePageManager;
import com.tanpu.community.manager.ThemeManager;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@RestController
@Slf4j
@RequestMapping(value = "/api/homepage")
public class HomePageController {

    @Autowired
    private HomePageManager homePageManager;

    @Autowired
    private ThemeManager themeManager;

    @Resource
    private UserHolder userHolder;

    
    @PostMapping(value = "/followList")
    @ApiOperation("查询关注/粉丝列表")
    @ResponseBody
    @AuthLogin
    public CommonResp<Page<FollowQo>> queryFollowList(@RequestBody QueryFollowReq req) {
        String userId = userHolder.getUserId();
        return CommonResp.success(homePageManager.queryFollow(req,userId));
    }

    @PostMapping(value = "/addIdol")
    @ApiOperation("关注/取消关注他人")
    @ResponseBody
    public CommonResp addIdol(@RequestBody FollowRelReq req) {
        String userId = userHolder.getUserId();
        homePageManager.addFollowRel(req,userId);
        return CommonResp.success();
    }

    @PostMapping(value = "/themeList")
    @ApiOperation("用户的帖子列表")
    @ResponseBody
    @AuthLogin
    public CommonResp<List<ThemeQo>> likeList(@Validated @RequestBody QueryRecordThemeReq req){
        String userId = userHolder.getUserId();
        return CommonResp.success(themeManager.queryThemesByUser(req,userId));
    }

}
